@@ -1,12 +1,13 @@
 from typing import Generator
 
+
 class Product:
     def __init__(self, raw) -> None:
         self.id = raw["_id"]
         self.product_id = raw["productId"]["_id"]
         self.name = raw["productId"]["productName"]
         self.desc = raw["productId"]["productDescription"]
-        self.price = int(raw["productPrice"])
+        self.price = float(raw["productPrice"])
         self.quantity = raw["productBaseQuantity"]
         self.stock = raw["productAvailability"] == "instock"
         self.__repr__ = self.__str__
@@ -23,10 +24,13 @@ class Catalog:
         self.products = [Product(x) for x in raw["productList"]]
 
     def find_by_id(self, id) -> Product:
-        return next(x for x in self.products if x.id == id)
+        try:
+            return next(filter(lambda x: x.product_id == id, self.products))
+        except:
+            return None
 
     def __iter__(self) -> Generator[Product, None, None]:
         yield from self.products
 
     def __len__(self) -> int:
-        return len(self.products)
\ No newline at end of file
+        return len(self.products)
