@@ -25,7 +25,14 @@ def download_catalog():
     ws = wb.active
     ws.title = "catalog"
     ws.append(
-        ["Product ID", "Product Name", "Description", "Price", "Base quantity", "In Stock?"]
+        [
+            "Product ID",
+            "Product Name",
+            "Description",
+            "Price",
+            "Base quantity",
+            "In Stock?",
+        ]
     )
     for product in catalog["productList"]:
         prodId = product["productId"]
