@@ -1,7 +1,7 @@
 import re
 from typing import Generator
-from kiraak.catalog import Product
 
+from kiraak.catalog import Product
 from kiraak.config import FLAT_RE
 
 
@@ -53,7 +53,12 @@ class OrderList:
         self.orders = [Order(x) for x in raw]
         self.all_products = [x for y in self.orders for x in y.prods]
         seen = set()
-        self.unique_products = [seen.add(x.name) or x for y in self.orders for x in y.prods if x.name not in seen]
+        self.unique_products = [
+            seen.add(x.name) or x
+            for y in self.orders
+            for x in y.prods
+            if x.name not in seen
+        ]
 
     def __iter__(self) -> Generator[Order, None, None]:
         yield from self.orders
