@@ -24,13 +24,6 @@ wcapi = API(
 
 logger = logging.getLogger(__name__)
 
-logger.info(f"Logging in as {Auth.MOBILE}")
-partner_info = login(Auth.MOBILE, Auth.PASSWORD)
-logger.info(
-    f"Logged in as {partner_info['partnerName']} @ {partner_info['partnerBrand']}"
-)
-
-
 class WC_Product:
     def __init__(self, raw_json) -> None:
         self.id = raw_json["id"]
@@ -44,7 +37,7 @@ class WC_Product:
             self.price = int(raw_json["price"])
             self.old_price = int(raw_json["price"])
         else:
-            logger.error("Product has no price!")
+            logger.error(f"Product {self.name!r} has no price!")
 
 
 class WC_Products:
@@ -103,19 +96,20 @@ def sync():
         ]
     }
     logger.info(f"Syncing {len(data['update'])} products...")
-    returned = wcapi.post("products/batch", data=data).json()
+    # returned = wcapi.post("products/batch", data=data).json()
     logger.info("Synced!")
 
-
-@click.command()
-@click.argument("time-gap", default=300, type=int)
-@click.option("--once", is_flag=True)
 def main(once, time_gap):
+    logger.info(f"Logging in as {Auth.MOBILE}")
+    partner_info = login(Auth.MOBILE, Auth.PASSWORD)
+    logger.info(
+        f"Logged in as {partner_info['partnerName']} @ {partner_info['partnerBrand']}"
+    )
+
     sync()
     while not once:
         time.sleep(time_gap)
         sync()
 
-
 if __name__ == "__main__":
     main()
